@@ -208,24 +208,25 @@ void mncc_call_detach_rtp_stream(struct mncc_call *mncc_call)
 
 static void mncc_call_tx_setup_ind(struct mncc_call *mncc_call)
 {
-	struct gsm_mncc mncc_msg = mncc_call->outgoing_req;
-	mncc_msg.msg_type = MNCC_SETUP_IND;
-	mncc_msg.callref = mncc_call->callref;
+	union mncc_msg mncc_msg;
+	mncc_msg.signal = mncc_call->outgoing_req;
+	mncc_msg.signal.msg_type = MNCC_SETUP_IND;
+	mncc_msg.signal.callref = mncc_call->callref;
 
-	OSMO_STRLCPY_ARRAY(mncc_msg.imsi, mncc_call->vsub->imsi);
+	OSMO_STRLCPY_ARRAY(mncc_msg.signal.imsi, mncc_call->vsub->imsi);
 
 	if (!(mncc_call->outgoing_req.fields & MNCC_F_CALLING)) {
 		/* No explicit calling number set, use the local subscriber */
-		mncc_msg.fields |= MNCC_F_CALLING;
-		OSMO_STRLCPY_ARRAY(mncc_msg.calling.number, mncc_call->vsub->msisdn);
+		mncc_msg.signal.fields |= MNCC_F_CALLING;
+		OSMO_STRLCPY_ARRAY(mncc_msg.signal.calling.number, mncc_call->vsub->msisdn);
 
 	}
 	mncc_call->local_msisdn_present = true;
-	mncc_call->local_msisdn = mncc_msg.calling;
+	mncc_call->local_msisdn = mncc_msg.signal.calling;
 
 	rate_ctr_inc(&gsmnet->msc_ctrs->ctr[MSC_CTR_CALL_MO_SETUP]);
 
-	mncc_call_tx(mncc_call, (union mncc_msg*)&mncc_msg);
+	mncc_call_tx(mncc_call, &mncc_msg);
 }
 
 static void mncc_call_rx_setup_req(struct mncc_call *mncc_call, const struct gsm_mncc *incoming_req)
@@ -303,11 +304,10 @@ static bool mncc_call_tx_rtp_create(struct mncc_call *mncc_call)
 		.rtp = {
 			.msg_type = MNCC_RTP_CREATE,
 			.callref = mncc_call->callref,
-			.port = rtp_local->port,
 		},
 	};
 
-	if (osmo_sockaddr_str_to_32n(rtp_local, &mncc_msg.rtp.ip)) {
+	if (osmo_sockaddr_str_to_sockaddr(rtp_local, &mncc_msg.rtp.addr)) {
 		mncc_call_error(mncc_call, "Failed to compose IP address " OSMO_SOCKADDR_STR_FMT "\n",
 				OSMO_SOCKADDR_STR_FMT_ARGS(rtp_local));
 		return false;
@@ -332,7 +332,7 @@ static bool mncc_call_rx_rtp_connect(struct mncc_call *mncc_call, const struct g
 		return true;
 	}
 
-	if (osmo_sockaddr_str_from_32n(&rtp, mncc_msg->ip, mncc_msg->port)) {
+	if (osmo_sockaddr_str_from_sockaddr(&rtp, &mncc_msg->addr)) {
 		mncc_call_error(mncc_call, "Cannot RTP-CONNECT, invalid RTP IP:port in incoming MNCC message\n");
 		return false;
 	}
