@@ -38,6 +38,7 @@
 #include <osmocom/core/logging.h>
 #include <osmocom/core/write_queue.h>
 #include <osmocom/core/talloc.h>
+#include <osmocom/gsm/protocol/gsm_04_11.h>
 
 #include "smpp_smsc.h"
 
@@ -327,9 +328,9 @@ int smpp_route(const struct smsc *smsc, const struct osmo_smpp_addr *dest, struc
 
 	*pesme = NULL;
 	if (acl)
-		return GSM48_CC_CAUSE_NETWORK_OOO;
+		return GSM411_RP_CAUSE_MO_NET_OUT_OF_ORDER;
 	else
-		return GSM48_CC_CAUSE_UNASSIGNED_NR;
+		return GSM411_RP_CAUSE_MO_NUM_UNASSIGNED;
 }
 
 
@@ -928,9 +929,7 @@ static int link_accept_cb(struct smsc *smsc, int fd,
 	esme_inc_seq_nr(esme);
 	esme->smsc = smsc;
 	osmo_wqueue_init(&esme->wqueue, 10);
-	esme->wqueue.bfd.fd = fd;
-	esme->wqueue.bfd.data = esme;
-	esme->wqueue.bfd.when = BSC_FD_READ;
+	osmo_fd_setup(&esme->wqueue.bfd, fd, OSMO_FD_READ, osmo_wqueue_bfd_cb, esme, 0);
 
 	if (osmo_fd_register(&esme->wqueue.bfd) != 0) {
 		close(fd);
